.. muses_doc documentation master file, created by
sphinx-quickstart on Sun Jan  5 10:52:17 2020.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive.

Welcome to muses_doc's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
